==> mafglib-0.4.0%2Bmc1.21.10-sources.jar: fi/dy/masa/malilib/gui/button/ConfigButtonLockedList.java <==
package fi.dy.masa.malilib.gui.button;

import javax.annotation.Nullable;

import net.minecraft.client.gui.Click;

import fi.dy.masa.malilib.config.IConfigLockedList;
import fi.dy.masa.malilib.gui.GuiBase;
import fi.dy.masa.malilib.gui.GuiLockedListEdit;
import fi.dy.masa.malilib.gui.interfaces.IConfigGui;
import fi.dy.masa.malilib.gui.interfaces.IDialogHandler;
import fi.dy.masa.malilib.util.GuiUtils;
import fi.dy.masa.malilib.util.StringUtils;

public class ConfigButtonLockedList extends ButtonGeneric
{
    private final IConfigLockedList config;
    private final IConfigGui configGui;
    @Nullable private final IDialogHandler dialogHandler;

    public ConfigButtonLockedList(int x, int y, int width, int height, IConfigLockedList config, IConfigGui configGui, @Nullable IDialogHandler dialogHandler)
    {
        super(x, y, width, height, "");

        this.config = config;
        this.configGui = configGui;
        this.dialogHandler = dialogHandler;

        this.updateDisplayString();
    }

    @Override
    protected boolean onMouseClickedImpl(Click click, boolean doubleClick)
    {
        super.onMouseClickedImpl(click, doubleClick);

        if (this.dialogHandler != null)
        {
            this.dialogHandler.openDialog(new GuiLockedListEdit(this.config, this.configGui, this.dialogHandler, null));
        }
        else
        {
            GuiBase.openGui(new GuiLockedListEdit(this.config, this.configGui, null, GuiUtils.getCurrentScreen()));
        }

        return true;
    }

    @Override
    public void updateDisplayString()
    {
        this.displayString = StringUtils.getClampedDisplayStringRenderlen(this.config.getConfigKeys(), this.width - 10, "[ ", " ]");
    }
}

==> mafglib-0.4.3%2Bmc1.21.8-sources.jar: fi/dy/masa/malilib/gui/button/ConfigButtonLockedList.java <==
package fi.dy.masa.malilib.gui.button;

import javax.annotation.Nullable;

import fi.dy.masa.malilib.config.IConfigLockedList;
import fi.dy.masa.malilib.gui.GuiBase;
import fi.dy.masa.malilib.gui.GuiLockedListEdit;
import fi.dy.masa.malilib.gui.interfaces.IConfigGui;
import fi.dy.masa.malilib.gui.interfaces.IDialogHandler;
import fi.dy.masa.malilib.util.GuiUtils;
import fi.dy.masa.malilib.util.StringUtils;

public class ConfigButtonLockedList extends ButtonGeneric
{
    private final IConfigLockedList config;
    private final IConfigGui configGui;
    @Nullable private final IDialogHandler dialogHandler;

    public ConfigButtonLockedList(int x, int y, int width, int height, IConfigLockedList config, IConfigGui configGui, @Nullable IDialogHandler dialogHandler)
    {
        super(x, y, width, height, "");

        this.config = config;
        this.configGui = configGui;
        this.dialogHandler = dialogHandler;

        this.updateDisplayString();
    }

    @Override
    protected boolean onMouseClickedImpl(int mouseX, int mouseY, int mouseButton)
    {
        super.onMouseClickedImpl(mouseX, mouseY, mouseButton);

        //RenderUtils.forceDraw(this.drawContext);
        //RenderUtils.depthTest(false);

        if (this.dialogHandler != null)
        {
            this.dialogHandler.openDialog(new GuiLockedListEdit(this.config, this.configGui, this.dialogHandler, null));
        }
        else
        {
            GuiBase.openGui(new GuiLockedListEdit(this.config, this.configGui, null, GuiUtils.getCurrentScreen()));
        }

        return true;
    }

    @Override
    public void updateDisplayString()
    {
        this.displayString = StringUtils.getClampedDisplayStringRenderlen(this.config.getConfigKeys(), this.width - 10, "[ ", " ]");
    }
}
